@@ -13,6 +13,7 @@ from talos.thrift.consumer.ttypes import UnlockPartitionRequest
 from talos.thrift.consumer.ttypes import LockPartitionRequest
 from talos.thrift.consumer.ttypes import LockPartitionResponse
 from talos.client.TalosClientFactory import ConsumerClient
+from talos.thrift.common.ttypes import GalaxyTalosException
 from talos.utils import Utils
 from talos.utils.Utils import synchronized
 import logging
@@ -121,7 +122,6 @@ class PartitionFetcher(object):
             self.messageReader.set_consumer_client(self.commitOffsetClient)
             self.messageReader.set_query_offset_client(self.queryPartitionClient)
             self.messageReader.set_outer_checkpoint(outerCheckPoint)
-            self.messageReader.init_consumer_metrics()
 
         self.logger.info("The PartitionFetcher for topic: " +
                          str(topicTalosResourceName.topicTalosResourceName)
@@ -132,18 +132,16 @@ class PartitionFetcher(object):
                          + str(self.partitionId))
 
         # try to lock partition from HBase, if failed, set to UNLOCKED and return;
-        try:
-            if not self.steal_partition():
-                self.update_state(TASK_STATE.UNLOCKED)
-                return
-        except Exception as e:
-            self.logger.error("Exception in steal_partition " + str(traceback.format_exc()))
+        if not self.steal_partition():
+            self.update_state(TASK_STATE.UNLOCKED)
             return
 
         # query start offset to read, if failed, clean and return;
         try:
             self.messageReader.init_start_offset()
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Worker: " + self.workerId + " query partition offset " +
                               "error: we will skip this partition" + str(traceback.format_exc()))
             self.clean()
@@ -252,6 +250,8 @@ class PartitionFetcher(object):
         try:
             self.consumerClient.unlock_partition(unlockRequest)
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.warn("Worker: " + self.workerId + " release partition error: "
                              + str(traceback.format_exc()))
             return
@@ -275,6 +275,8 @@ class PartitionFetcher(object):
         try:
             lockResponse = self.consumerClient.lock_partition(lockRequest)
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Worker: " + self.workerId + " steal partition id : "
                               + str(self.partitionId) + " error! " + str(traceback.format_exc()))
             return False
@@ -282,10 +284,7 @@ class PartitionFetcher(object):
         # get the successfully locked partition
         successPartitionList = lockResponse.successPartitions
         if len(successPartitionList) > 0:
-            try
-                assert successPartitionList[0] == self.partitionId
-            except AssertionError as e:
-                raise e
+            assert successPartitionList[0] == self.partitionId
             self.logger.info("Worker: " + self.workerId + " success to lock partitions: "
                              + str(self.partitionId))
             return True
@@ -299,9 +298,6 @@ class PartitionFetcher(object):
         self.release_partition()
         self.update_state(TASK_STATE.UNLOCKED)
 
-    def get_falcon_data(self):
-        return self.messageReader.get_consumer_metrics().to_json_data()
-
     def shutdown(self):
         # set UNLOCKING to stop read and wait fetcher gracefully quit
         self.update_state(TASK_STATE.UNLOCKING)
